@@ -57,6 +57,8 @@ modelcheck.lm = function(x, which = 1:3, mar = c(3, 4, 1.5, 4), ...) {
   M = createLayoutMatrix()
   layout(M)
   oldPar = par("mar","mgp")
+  on.exit(par(oldPar))
+  
   par(mar = mar, mgp = c(2, 1, 0))
   
   if (1 %in% which){
@@ -72,6 +74,6 @@ modelcheck.lm = function(x, which = 1:3, mar = c(3, 4, 1.5, 4), ...) {
     plot(x, which = 4, ...)
   }
   
-  par(oldPar)
+
   layout(1)
 }
\ No newline at end of file
